pub enum DecodingResult {
U8(Vec<u8>),
U16(Vec<u16>),
U32(Vec<u32>),
U64(Vec<u64>),
F16(Vec<f16>),
F32(Vec<f32>),
F64(Vec<f64>),
I8(Vec<i8>),
I16(Vec<i16>),
I32(Vec<i32>),
I64(Vec<i64>),
}Expand description
Result of a decoding process
Variants
U8(Vec<u8>)
A vector of unsigned bytes
U16(Vec<u16>)
A vector of unsigned words
U32(Vec<u32>)
A vector of 32 bit unsigned ints
U64(Vec<u64>)
A vector of 64 bit unsigned ints
F16(Vec<f16>)
A vector of 16 bit IEEE floats (held in u16)
F32(Vec<f32>)
A vector of 32 bit IEEE floats
F64(Vec<f64>)
A vector of 64 bit IEEE floats
I8(Vec<i8>)
A vector of 8 bit signed ints
I16(Vec<i16>)
A vector of 16 bit signed ints
I32(Vec<i32>)
A vector of 32 bit signed ints
I64(Vec<i64>)
A vector of 64 bit signed ints
Implementations
Sourceimpl DecodingResult
impl DecodingResult
Sourcepub fn resize_to(
&mut self,
buffer: &BufferLayoutPreference,
limits: &Limits,
) -> Result<(), TiffError>
pub fn resize_to( &mut self, buffer: &BufferLayoutPreference, limits: &Limits, ) -> Result<(), TiffError>
Reallocate the buffer to decode all planes of the indicated layout.
Sourcepub fn as_buffer(&mut self, start: usize) -> DecodingBuffer<'_>
pub fn as_buffer(&mut self, start: usize) -> DecodingBuffer<'_>
Get a view of this buffer starting from the nth sample of the current type.